==> apache-skywalking-satellite-1.0.0-src.tgz: apache-skywalking-satellite-1.0.0/docs/en/setup/plugins/plugin-list.md <==
# Plugin List
- Client
	- [GRPC Client](./client_grpc-client.md)
	- [Kafka Client](./client_kafka-client.md)
- Fallbacker
	- [None Fallbacker](./fallbacker_none-fallbacker.md)
	- [Timer Fallbacker](./fallbacker_timer-fallbacker.md)
- Fetcher
	- [Prometheus Metrics Fetcher](./fetcher_prometheus-metrics-fetcher.md)
- Filter
- Forwarder
	- [Envoy ALS v2 GRPC Forwarder](./forwarder_envoy-als-v2-grpc-forwarder.md)
	- [Envoy ALS v3 GRPC Forwarder](./forwarder_envoy-als-v3-grpc-forwarder.md)
	- [Envoy Metrics v2 GRPC Forwarder](./forwarder_envoy-metrics-v2-grpc-forwarder.md)
	- [Envoy Metrics v3 GRPC Forwarder](./forwarder_envoy-metrics-v3-grpc-forwarder.md)
	- [Native CDS GRPC Forwarder](./forwarder_native-cds-grpc-forwarder.md)
	- [Native EBPF Profiling GRPC Forwarder](./forwarder_native-ebpf-profiling-grpc-forwarder.md)
	- [Native Event GRPC Forwarder](./forwarder_native-event-grpc-forwarder.md)
	- [Native JVM GRPC Forwarder](./forwarder_native-jvm-grpc-forwarder.md)
	- [Native Log GRPC Forwarder](./forwarder_native-log-grpc-forwarder.md)
	- [Native Log Kafka Forwarder](./forwarder_native-log-kafka-forwarder.md)
	- [Native Management GRPC Forwarder](./forwarder_native-management-grpc-forwarder.md)
	- [Native Meter GRPC Forwarder](./forwarder_native-meter-grpc-forwarder.md)
	- [Native Process GRPC Forwarder](./forwarder_native-process-grpc-forwarder.md)
	- [Native Profile GRPC Forwarder](./forwarder_native-profile-grpc-forwarder.md)
	- [Native Tracing GRPC Forwarder](./forwarder_native-tracing-grpc-forwarder.md)
- Parser
- Queue
	- [Memory Queue](./queue_memory-queue.md)
	- [Mmap Queue](./queue_mmap-queue.md)
	- [None Queue](./queue_none-queue.md)
- Receiver
	- [GRPC Envoy ALS v2 Receiver](./receiver_grpc-envoy-als-v2-receiver.md)
	- [GRPC Envoy ALS v3 Receiver](./receiver_grpc-envoy-als-v3-receiver.md)
	- [GRPC Envoy Metrics v2 Receiver](./receiver_grpc-envoy-metrics-v2-receiver.md)
	- [GRPC Envoy Metrics v3 Receiver](./receiver_grpc-envoy-metrics-v3-receiver.md)
	- [GRPC Native CDS Receiver](./receiver_grpc-native-cds-receiver.md)
	- [GRPC Native EBFP Profiling Receiver](./receiver_grpc-native-ebpf-profiling-receiver.md)
	- [GRPC Native Event Receiver](./receiver_grpc-native-event-receiver.md)
	- [GRPC Native JVM Receiver](./receiver_grpc-native-jvm-receiver.md)
	- [GRPC Native Log Receiver](./receiver_grpc-native-log-receiver.md)
	- [GRPC Native Management Receiver](./receiver_grpc-native-management-receiver.md)
	- [GRPC Native Meter Receiver](./receiver_grpc-native-meter-receiver.md)
	- [GRPC Native Process Receiver](./receiver_grpc-native-process-receiver.md)
	- [GRPC Native Profile Receiver](./receiver_grpc-native-profile-receiver.md)
	- [GRPC Native Tracing Receiver](./receiver_grpc-native-tracing-receiver.md)
	- [HTTP Native Log Receiver](./receiver_http-native-log-receiver.md)
- Server
	- [GRPC Server](./server_grpc-server.md)
	- [HTTP Server](./server_http-server.md)

==> apache-skywalking-satellite-1.2.0-src.tgz: apache-skywalking-satellite-1.2.0/docs/en/setup/plugins/plugin-list.md <==
# Plugin List
- Client
	- [GRPC Client](./client_grpc-client.md)
	- [Kafka Client](./client_kafka-client.md)
- Fallbacker
	- [None Fallbacker](./fallbacker_none-fallbacker.md)
	- [Timer Fallbacker](./fallbacker_timer-fallbacker.md)
- Fetcher
- Filter
- Forwarder
	- [Envoy ALS v2 GRPC Forwarder](./forwarder_envoy-als-v2-grpc-forwarder.md)
	- [Envoy ALS v3 GRPC Forwarder](./forwarder_envoy-als-v3-grpc-forwarder.md)
	- [Envoy Metrics v2 GRPC Forwarder](./forwarder_envoy-metrics-v2-grpc-forwarder.md)
	- [Envoy Metrics v3 GRPC Forwarder](./forwarder_envoy-metrics-v3-grpc-forwarder.md)
	- [Native CDS GRPC Forwarder](./forwarder_native-cds-grpc-forwarder.md)
	- [Native EBPF Profiling GRPC Forwarder](./forwarder_native-ebpf-profiling-grpc-forwarder.md)
	- [Native Event GRPC Forwarder](./forwarder_native-event-grpc-forwarder.md)
	- [Native JVM GRPC Forwarder](./forwarder_native-jvm-grpc-forwarder.md)
	- [Native CLR GRPC Forwarder](./forwarder_native-clr-grpc-forwarder.md)
	- [Native Log GRPC Forwarder](./forwarder_native-log-grpc-forwarder.md)
	- [Native Log Kafka Forwarder](./forwarder_native-log-kafka-forwarder.md)
	- [Native Management GRPC Forwarder](./forwarder_native-management-grpc-forwarder.md)
	- [Native Meter GRPC Forwarder](./forwarder_native-meter-grpc-forwarder.md)
	- [Native Process GRPC Forwarder](./forwarder_native-process-grpc-forwarder.md)
	- [Native Profile GRPC Forwarder](./forwarder_native-profile-grpc-forwarder.md)
	- [Native Tracing GRPC Forwarder](./forwarder_native-tracing-grpc-forwarder.md)
	- [OpenTelemetry Metrics v1 GRPC Forwarder](./forwarder_otlp-metrics-v1-grpc-forwarder.md)
- Parser
- Queue
	- [Memory Queue](./queue_memory-queue.md)
	- [Mmap Queue](./queue_mmap-queue.md)
	- [None Queue](./queue_none-queue.md)
- Receiver
	- [GRPC Envoy ALS v2 Receiver](./receiver_grpc-envoy-als-v2-receiver.md)
	- [GRPC Envoy ALS v3 Receiver](./receiver_grpc-envoy-als-v3-receiver.md)
	- [GRPC Envoy Metrics v2 Receiver](./receiver_grpc-envoy-metrics-v2-receiver.md)
	- [GRPC Envoy Metrics v3 Receiver](./receiver_grpc-envoy-metrics-v3-receiver.md)
	- [GRPC Native CDS Receiver](./receiver_grpc-native-cds-receiver.md)
	- [GRPC Native EBFP Profiling Receiver](./receiver_grpc-native-ebpf-profiling-receiver.md)
	- [GRPC Native Event Receiver](./receiver_grpc-native-event-receiver.md)
	- [GRPC Native JVM Receiver](./receiver_grpc-native-jvm-receiver.md)
	- [GRPC Native CLR Receiver](./receiver_grpc-native-clr-receiver.md)
	- [GRPC Native Log Receiver](./receiver_grpc-native-log-receiver.md)
	- [GRPC Native Management Receiver](./receiver_grpc-native-management-receiver.md)
	- [GRPC Native Meter Receiver](./receiver_grpc-native-meter-receiver.md)
	- [GRPC Native Process Receiver](./receiver_grpc-native-process-receiver.md)
	- [GRPC Native Profile Receiver](./receiver_grpc-native-profile-receiver.md)
	- [GRPC Native Tracing Receiver](./receiver_grpc-native-tracing-receiver.md)
	- [GRPC OpenTelemetry Metrics v1 Receiver](./receiver_grpc-otlp-metrics-v1-receiver.md)
	- [HTTP Native Log Receiver](./receiver_http-native-log-receiver.md)
- Server
	- [GRPC Server](./server_grpc-server.md)
	- [HTTP Server](./server_http-server.md)
